# pds.api-client
Registry API enabling advanced search on PDS data and metadata. The API provides end-points to search for bundles, collections and any PDS products with advanced search queries. It also enables to browse the archive hierarchically downward (e.g. collection/s products) or upward (e.g. bundles containing a product).
The detailed syntax for querying the end-point is given in the reference documentation.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pds.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pds.api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import pds.api_client
from pprint import pprint
from pds.api_client.api import bundles_api
from pds.api_client.model.error_message import ErrorMessage
from pds.api_client.model.pds_product import PdsProduct
from pds.api_client.model.pds_products import PdsProducts
# Defining the host is optional and defaults to https://pds.nasa.gov/api/registry/1.0
# See configuration.py for a list of all supported configuration parameters.
configuration = pds.api_client.Configuration(
    host = "https://pds.nasa.gov/api/registry/1.0"
)



# Enter a context with an instance of the API client
with pds.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = bundles_api.BundlesApi(api_client)
    identifier = "identifier_example" # str | syntax: lidvid or lid  behavior (lid): returns one or more items whose lid matches this lid exactly. If the endpoint ends with the identifier or /latest then a signle result is returned and it is the highest version. If the endpoint ends with /all then all versions of the lid are returned.  behavior (lidvid): returns one and only one item whose lidvid matches this lidvid exactly.  note: the current lid/lidvid resolution will match all the lids that start with lid. In other words, it acts like a glob of foobar*. It behaves this way from first character to the last  note: simple sorting of the lidvid is being done to select the latest from the end of the list. However, the versions 1.0, 2.0, and 13.0 will sort to 1.0, 13.0, and 2.0 so the end of the list may not be the latest. 
fields = [
        "fields_example",
    ] # [str] | syntax: fields=field1,field2,...  behavior: this parameter and the headder Accept: type determine what content is packaged for the result. While the types application/csv, application/kvp+json, and text/csv return only the fields requesteted, all of the other types have a minimal set of fields that must be returned. Duplicating a minimally required field in this parameter has not effect. The types vnd.nasa.pds.pds4+json and vnd.nasa.pds.pds4+xml have a complete set of fields that must be returned; meaning this parameter does not impact their content. When fields is not used, then the minimal set of fields, or all when minimal is an empty set, is returned.  notes: the blob fields are blocked unless specifically requrested and only for the */csv and application/kvp+csv types.  (optional)

    try:
        # returns one product with the identifier selected from all PDS bundles. See identifier for details on how it determines what is returned. 
        api_response = api_instance.bundle_by_lidvid(identifier, fields=fields)
        pprint(api_response)
    except pds.api_client.ApiException as e:
        print("Exception when calling BundlesApi->bundle_by_lidvid: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://pds.nasa.gov/api/registry/1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BundlesApi* | [**bundle_by_lidvid**](docs/BundlesApi.md#bundle_by_lidvid) | **GET** /bundles/{identifier} | returns one product with the identifier selected from all PDS bundles. See identifier for details on how it determines what is returned. 
*BundlesApi* | [**bundle_by_lidvid_all**](docs/BundlesApi.md#bundle_by_lidvid_all) | **GET** /bundles/{identifier}/all | returns all product versions with the identifier (lid) selected from all PDS bundles. See identifier for details on how it determines what is returned. 
*BundlesApi* | [**bundle_by_lidvid_latest**](docs/BundlesApi.md#bundle_by_lidvid_latest) | **GET** /bundles/{identifier}/latest | returns one product with the identifier selected from all PDS bundles. See identifier for details on how it determines what is returned. 
*BundlesApi* | [**get_bundles**](docs/BundlesApi.md#get_bundles) | **GET** /bundles | returns all PDS bundles that meet all given constraints. 
*BundlesCollectionsApi* | [**collections_of_a_bundle**](docs/BundlesCollectionsApi.md#collections_of_a_bundle) | **GET** /bundles/{identifier}/collections | returns one or more latest version collections that are contained or referenced by the bundle specified by identifier. See identifier for details on how it determines what is returned. 
*BundlesCollectionsApi* | [**collections_of_a_bundle_all**](docs/BundlesCollectionsApi.md#collections_of_a_bundle_all) | **GET** /bundles/{identifier}/collections/all | returns one or more collections that are contained or referenced by the bundle specified by identifier. See identifier for details on how it determines what is returned. 
*BundlesCollectionsApi* | [**collections_of_a_bundle_latest**](docs/BundlesCollectionsApi.md#collections_of_a_bundle_latest) | **GET** /bundles/{identifier}/collections/latest | returns one or more latest version collections that are contained or referenced by the bundle specified by identifier. See identifier for details on how it determines what is returned. 
*BundlesProductsApi* | [**products_of_a_bundle**](docs/BundlesProductsApi.md#products_of_a_bundle) | **GET** /bundles/{identifier}/products | returns one or more latest version products that are contained or referenced by the bundle specified by identifier. See identifier for details on how it determines what is returned. 
*CollectionsApi* | [**collections_by_lidvid**](docs/CollectionsApi.md#collections_by_lidvid) | **GET** /collections/{identifier} | returns one product with the identifier selected from all PDS collections. See identifier for details on how it determines what is returned. 
*CollectionsApi* | [**collections_by_lidvid_all**](docs/CollectionsApi.md#collections_by_lidvid_all) | **GET** /collections/{identifier}/all | returns all collection versions with the identifier (lid) selected from all PDS collections. See identifier for details on how it determines what is returned. 
*CollectionsApi* | [**collections_by_lidvid_latest**](docs/CollectionsApi.md#collections_by_lidvid_latest) | **GET** /collections/{identifier}/latest | returns one product with the identifier selected from all PDS collections. See identifier for details on how it determines what is returned. 
*CollectionsApi* | [**get_collection**](docs/CollectionsApi.md#get_collection) | **GET** /collections | returns all PDS collections that meet all given constraints. 
*CollectionsContainingBundlesApi* | [**bundles_containing_collection**](docs/CollectionsContainingBundlesApi.md#bundles_containing_collection) | **GET** /collections/{identifier}/bundles | returns one or more bundles that contain or reference the product specified by identifier selected from all PDS collections. See identifier for details on how it determines what is returned. 
*CollectionsProductsApi* | [**products_of_a_collection**](docs/CollectionsProductsApi.md#products_of_a_collection) | **GET** /collections/{identifier}/products | returns one or more latest version products that are contained or referenced by the collection specified by identifier. See identifier for details on how it determines what is returned. 
*CollectionsProductsApi* | [**products_of_a_collection_all**](docs/CollectionsProductsApi.md#products_of_a_collection_all) | **GET** /collections/{identifier}/products/all | returns one or more products that are contained or referenced by the collection specified by identifier. See identifier for details on how it determines what is returned. 
*CollectionsProductsApi* | [**products_of_a_collection_latest**](docs/CollectionsProductsApi.md#products_of_a_collection_latest) | **GET** /collections/{identifier}/products/latest | returns one or more latest version products that are contained or referenced by the collection specified by identifier. See identifier for details on how it determines what is returned. 
*ProductContainingCollectionsApi* | [**collections_containing_product**](docs/ProductContainingCollectionsApi.md#collections_containing_product) | **GET** /products/{identifier}/collections | returns one or more collections that contain or reference the product specified by identifier selected from all PDS data products, including bundles, collections, documentation, context and observational products. See identifier for details on how it determines what is returned.         
*ProductsApi* | [**products**](docs/ProductsApi.md#products) | **GET** /products | returns all PDS data products, including bundles, collections, documentation, context and observational products that meet all given constraints. 
*ProductsApi* | [**products_by_lidvid**](docs/ProductsApi.md#products_by_lidvid) | **GET** /products/{identifier} | returns one product with the identifier selected from all PDS data products, including bundles, collections, documentation, context and observational products. See identifier for details on how it determines what is returned. 
*ProductsApi* | [**products_by_lidvid_all**](docs/ProductsApi.md#products_by_lidvid_all) | **GET** /products/{identifier}/all | returns all product versions with the identifier (lid) selected from all PDS data products, including bundles, collections, documentation, context and observational products. See identifier for details on how it determines what is returned. 
*ProductsApi* | [**products_by_lidvid_latest**](docs/ProductsApi.md#products_by_lidvid_latest) | **GET** /products/{identifier}/latest | returns one product with the identifier selected from all PDS data products, including bundles, collections, documentation, context and observational products. See identifier for details on how it determines what is returned. 
*ProductsContainingBundlesApi* | [**bundles_containing_product**](docs/ProductsContainingBundlesApi.md#bundles_containing_product) | **GET** /products/{identifier}/bundles | returns one or more bundles that contain or reference the product specified by identifier selected from all PDS data products, including bundles, collections, documentation, context and observational products. See identifier for details on how it determines what is returned. 


## Documentation For Models

 - [ErrorMessage](docs/ErrorMessage.md)
 - [Metadata](docs/Metadata.md)
 - [Pds4Metadata](docs/Pds4Metadata.md)
 - [Pds4MetadataOpsDataFiles](docs/Pds4MetadataOpsDataFiles.md)
 - [Pds4MetadataOpsLabelFileInfo](docs/Pds4MetadataOpsLabelFileInfo.md)
 - [Pds4MetadataOpsTrackingMeta](docs/Pds4MetadataOpsTrackingMeta.md)
 - [Pds4Product](docs/Pds4Product.md)
 - [Pds4Products](docs/Pds4Products.md)
 - [PdsProduct](docs/PdsProduct.md)
 - [PdsProducts](docs/PdsProducts.md)
 - [PropertyArrayValues](docs/PropertyArrayValues.md)
 - [Reference](docs/Reference.md)
 - [Summary](docs/Summary.md)
 - [WyriwygProduct](docs/WyriwygProduct.md)
 - [WyriwygProductKeyValuePairs](docs/WyriwygProductKeyValuePairs.md)
 - [WyriwygProducts](docs/WyriwygProducts.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

pds-operator@jpl.nasa.gov


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in pds.api_client.apis and pds.api_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from pds.api_client.api.default_api import DefaultApi`
- `from pds.api_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import pds.api_client
from pds.api_client.apis import *
from pds.api_client.models import *
```

